package com.trs.ggzyexchange.schedul;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.trs.ggzyexchange.controller.AreaDataName;
import com.trs.ggzyexchange.entity.*;
import com.trs.ggzyexchange.enums.ClassIfy;
import com.trs.ggzyexchange.enums.JobLock;
import com.trs.ggzyexchange.service.*;
import com.trs.ggzyexchange.utils.TenderDetailsVoUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.elasticsearch.client.ml.EvaluateDataFrameRequest;
import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 招标文件/招标文件澄清与修改 定时任务
 * </p>
 *
 * @author trs
 * @since 2023-02-16
 */
@Component
public class YcNoticeSchedul implements Job {

    private Logger logger = LoggerFactory.getLogger(YcNoticeSchedul.class);

    @Autowired
    private AreaDataName areaDataName;

    @Autowired
    private GcNoticeandfileService gcNoticeandfileService;

    @Autowired
    private YcNoticeService ycNoticeService;

    @Autowired
    private ScheduledTashService scheduledTashService;

    @Autowired
    private AreaPlatformService areaPlatformService;

    public void queryPageListUpdateEs() throws JsonProcessingException {
        /**
         * 查询当前在定时任务表当中的最新时间
         */
        QueryWrapper<ScheduledTash> scheduledTashQueryWrapper = new QueryWrapper<ScheduledTash>();
        scheduledTashQueryWrapper.eq("table_name_value","yc_notice");
        Page<ScheduledTash> pageScheduledTash = new Page<ScheduledTash>(1, 1);
        Page<ScheduledTash> page = scheduledTashService.page(pageScheduledTash, scheduledTashQueryWrapper);
        List<ScheduledTash> records = page.getRecords();
        ScheduledTash scheduledTash = null;
        if(records.size() > 0){
            scheduledTash = records.get(0);
        }
        Long time = null;
        if(ObjectUtils.isEmpty(scheduledTash)){
            try {
                /**
                 * 如果scheduledTash为空，证明没有当前定时任务，设置当前的定时任务的时间为0  查询表gcNoticeandfile表当中的最新时间
                 */
                time = ycNoticeService.maxDataTimeStamp();
                ScheduledTash scheduledTashTash = new ScheduledTash();
                scheduledTashTash.setTime(0L);
                time = 0L;
                scheduledTashTash.setTableNameValue("yc_notice");
                scheduledTashTash.setUpdateTime(new Date());
                scheduledTashTash.setCreateTime(new Date());
                scheduledTashService.saveOrUpdate(scheduledTashTash,scheduledTashQueryWrapper);
            }catch (Exception e){
                e.printStackTrace();
            }
        }else {
            /**
             * 如果scheduledTash为空，证明没有当前定时任务，设置当前的定时任务的时间为0  查询表gcNoticeandfile表当中的最新时间
             */
            time = scheduledTash.getTime();
        }
        try {
            //查询表gcNoticeandfile表当中的最新时间
            Long newTime = ycNoticeService.maxDataTimeStamp();
            ScheduledTash scheduledTashTash = new ScheduledTash();
            scheduledTashTash.setTime(newTime);
            scheduledTashTash.setTableNameValue("yc_notice");
            scheduledTashTash.setUpdateTime(new Date());
            scheduledTashService.saveOrUpdate(scheduledTashTash,scheduledTashQueryWrapper);
        }catch (Exception e){
            e.printStackTrace();
        }
        if(!ObjectUtils.isEmpty(time)){
            try {
                QueryWrapper<YcNotice> ycNoticeQueryWrapper = new QueryWrapper<YcNotice>();
                ycNoticeQueryWrapper.gt("DATE",time);
                int count = ycNoticeService.count(ycNoticeQueryWrapper);
                Integer pageSize = 1000;
                Integer pageNum = (int)Math.ceil((double)count/pageSize);
                for(int i = 1; i <= pageNum;i++){
                   try {
                       List<TenderDetailsVo> tenderDetailsVoListAll = getTenderDetailsVoListAll(i, pageSize,time);
                       Boolean aBoolean = gcNoticeandfileService.parseTenderDetailsVoNoTime(tenderDetailsVoListAll);
                   }catch (Exception e){
                       e.printStackTrace();
                   }
                }
            }catch (Exception e){
                e.printStackTrace();
            }
        }
    }
    public List<TenderDetailsVo> getTenderDetailsVoListAll(Integer pageNo,Integer pageSize,Long time){
        Page<GcTenderbidfile> page = new Page<GcTenderbidfile>(pageNo, pageSize);
        IPage<TenderDetailsVo> tenderDetailsVoIPage = ycNoticeService.queryYcNoticeAllListByTime(page,time);
        for (TenderDetailsVo record : tenderDetailsVoIPage.getRecords()) {
            String projectName = record.getProjectName();
            if(!ObjectUtils.isEmpty(projectName)){
                record.setNoticeName(projectName);
            }
            String sourceDataKey = record.getSourceDataKey();
            sourceDataKey = sourceDataKey + record.getNoticeSendTime();
            record.setPlatformCode("121500004600236091");
            record.setPlatformName("内蒙古自治区本级");
            record.setSourceDataKey(sourceDataKey);
            record.setNoticeTypeCode(ClassIfy.MEDICAL_TRANSACTION_ANNOUNCEMENT.getCode());
            record.setNoticeTypeName(ClassIfy.MEDICAL_TRANSACTION_ANNOUNCEMENT.getName());
            record.setTransactionTypeCode(ClassIfy.MEDICAL.getCode());
            record.setTransactionTypeName(ClassIfy.MEDICAL.getName());
            TenderDetailsVoUtils.isNull(record);
        }
        return tenderDetailsVoIPage.getRecords();
    }

    @Override
    public void execute(JobExecutionContext jobExecutionContext) throws JobExecutionException {
        try {
            if(JobLock.YcNoticeFlag){
                JobLock.YcNoticeFlag = false;
                logger.info("执行YcNoticeFlag", new SimpleDateFormat().format(new Date()));
                try {
                    queryPageListUpdateEs();
                } catch (Exception e) {
                    e.printStackTrace();
                }
                JobLock.YcNoticeFlag = true;
            }else{
                logger.info("不执行YcNoticeFlag", new SimpleDateFormat().format(new Date()));
            }
        }catch (Exception e){
            e.printStackTrace();
            JobLock.YcNoticeFlag = true;
        }
    }

    public void execute() throws JobExecutionException {
        try {
            if(JobLock.YcNoticeFlag){
                JobLock.YcNoticeFlag = false;
                logger.info("执行YcNoticeFlag", new SimpleDateFormat().format(new Date()));
                try {
                    queryPageListUpdateEs();
                } catch (Exception e) {
                    e.printStackTrace();
                }
                JobLock.YcNoticeFlag = true;
            }else{
                logger.info("不执行YcNoticeFlag", new SimpleDateFormat().format(new Date()));
            }
        }catch (Exception e){
            e.printStackTrace();
            JobLock.YcNoticeFlag = true;
        }
    }

}
